jenkins:
  client:
    enabled: true
    audittrail:
      pattern: '.*'
      loggers:
        log_to_file:
          type: file
          log: "/var/log/jenkins_audit.log"
          limit: 100
          count: 10
        log_to_syslog:
          type: syslog
          syslog_server_hostname: example.syslog.com
          syslog_facility: LOCAL0
          message_hostname: example.jenkins.com
        log_to_console:
           output: STD_OUT
           date_format: "yyyy-MM-dd HH:mm:ss:SSS"
    flowdurabilitylevel: PERFORMANCE_OPTIMIZED
    master:
      host: jenkins.example.com
      port: 80
      protocol: http
    location:
      url: http://jenkins.example.com:80
    job:
      jobname:
        type: workflow
        param:
          bool_param:
            type: boolean
            description: true/false
            default: true
          string_param:
            type: string
            description: 1 liner
            default: default_string
          text_param:
            type: text
            description: multi-liner
            default: default_text
      jobname_scm:
        type: workflow-scm
        concurrent: false
        scm:
          type: git
          url: https://github.com/jenkinsci/docker.git
          branch: master
          script: Jenkinsfile
          remote_name: origin
          refspec: "$ref"
          wipe_workspace: true
          github:
            url: https://github.com/jenkinsci/docker
            name: "Jenkins Docker Image"
        trigger:
          timer:
            spec: "H H * * *"
          github: {}
          pollscm:
            spec: "H/15 * * * *"
          reverse:
            projects:
              - test1
              - test2
            state: SUCCESS
        param:
          bool_param:
            type: boolean
            description: true/false
            default: true
          ref:
            type: string
            description: ref
            default: ""
          string_param:
            type: string
            description: 1 liner
            default: default_string
          text_param:
            type: text
            description: multi-liner
            default: default_text
    job_template:
      template_name:
        jobs:
          - name: os
            salt_url: http://localhost:6969
        name: deploy-\{\{name}}
        template:
          concurrent: false
          discard:
            artifact:
              keep_num: 10
            build:
              keep_num: 10
          display_name: Deploy \{\{name}}
          param:
            SALT_MASTER_URL:
              default: '\{\{salt_url}}'
              type: string
          trigger:
            pollscm:
              spec: "H/60 * * * *"
          scm:
            branch: master
            credentials: gerrit
            script: Jenkinsfile
            type: git
            url: ssh://admin@localhost:29418/project/\{\{name}}
          type: workflow-scm
    approved_scripts:
      - method groovy.json.JsonSlurperClassic parseText java.lang.String
java:
  environment:
    enabled: true
    version: '11'
    release: '0.1'
    build: '13'
    oracle_hash: '90cf5d8f270a4347a95050320eef3fb7'
    platform: oracle-java
    development: true
